.. :changelog:

0.0 (September 2015)
++++++++++++++++++

- Creation.

  
0.2.5 (March 2016)
++++++++++++++++++

- Added compatibility with python3.5
- Added public access functionality  

0.2.6 (August 2016)
++++++++++++++++++

- Updated archive URL
